@@ -58,7 +58,7 @@ enum iso8601_date_prec {
 
     /*! \brief Year, week and weekday specified (week format). */
     iso8601_prec_wday
-}date_prec;
+};
 
 
 
@@ -87,7 +87,7 @@ enum iso8601_time_prec {
     iso8601_prec_minfrac,
     /*! \brief Display hour, minute, second and nanoseconds. */
     iso8601_prec_secfrac
-}time_prec;
+};
 
 
 
